@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this product; see the file COPYING.  If not, write to
-   the Free Software Foundation, 59 Temple Place - Suite 330, Boston, MA
-   02111-1307, USA.  */
+   the Free Software Foundation, 51 Franklin Street, Fifth Floor,
+   Boston, MA  02110-1301, USA.  */
 
 /* Copyright (c) 1983 Regents of the University of California.
    All rights reserved.
